==> haskell-vty-5.24-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vty
version: 5.24
id: vty-5.24-JmD3l917sdAHcppZY5zmFQ
key: vty-5.24-JmD3l917sdAHcppZY5zmFQ
license: BSD-3-Clause
maintainer: Jonathan Daugherty (cygnus@foobox.com)
author: AUTHORS
homepage: https://github.com/jtdaugherty/vty
synopsis: A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.
    .
    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.
    .
    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.
    .
    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.
    .
    &#169; Corey O'\''Connor; BSD3 license.
    .
    &#169; Jonathan Daugherty; BSD3 license.
category: User Interfaces
abi: b6d99865a746ce0389dce6b63be66f1a
exposed: True
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
hidden-modules: Graphics.Vty.Attributes.Color
                Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
                Graphics.Vty.Input.Terminfo.ANSIVT
import-dirs: /usr/lib/ghc-8.4.3/site-local/vty-5.24
library-dirs: /usr/lib/ghc-8.4.3/site-local/vty-5.24
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/vty-5.24
hs-libraries: HSvty-5.24-JmD3l917sdAHcppZY5zmFQ
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    bytestring-0.10.8.2 containers-0.5.11.0 deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh
    microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5
    microlens-th-0.4.2.2-CtKFRxCaH8TKvI1HPe9Q9y
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg mtl-2.2.2
    parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS parsec-3.1.13.0 stm-2.4.5.0
    terminfo-0.4.1.1 transformers-0.5.5.0 text-1.2.3.0 unix-2.7.2.2
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh=ea4e8465edaf940bc6b809afec7d8a0c
             microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5=1a8e1231c2e84cbd42a7eb5d31204255
             microlens-th-0.4.2.2-CtKFRxCaH8TKvI1HPe9Q9y=57e31df6646ed91dcbc51d429799fca5
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS=bfa6d2c22d7e7c439a84add8c91d8e7a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             terminfo-0.4.1.1=f198095a593060871f229adb71186f33
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html: /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-5.24-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vty
version: 5.24
id: vty-5.24-LEIHQXr0FZ94a5H6Aph9L
key: vty-5.24-LEIHQXr0FZ94a5H6Aph9L
license: BSD-3-Clause
maintainer: Jonathan Daugherty (cygnus@foobox.com)
author: AUTHORS
homepage: https://github.com/jtdaugherty/vty
synopsis: A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.
    .
    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.
    .
    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.
    .
    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.
    .
    &#169; Corey O'\''Connor; BSD3 license.
    .
    &#169; Jonathan Daugherty; BSD3 license.
category: User Interfaces
abi: 03dca5dba45d4d8c8f5b796a8073e089
exposed: True
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
hidden-modules: Graphics.Vty.Attributes.Color
                Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
                Graphics.Vty.Input.Terminfo.ANSIVT
import-dirs: /usr/lib/ghc-8.4.3/site-local/vty-5.24
library-dirs: /usr/lib/ghc-8.4.3/site-local/vty-5.24
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/vty-5.24
hs-libraries: HSvty-5.24-LEIHQXr0FZ94a5H6Aph9L
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    bytestring-0.10.8.2 containers-0.5.11.0 deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh
    microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5
    microlens-th-0.4.2.3-AFinaMAgvMDE4Aie8g4V0i
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg mtl-2.2.2
    parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS parsec-3.1.13.0 stm-2.4.5.0
    terminfo-0.4.1.1 transformers-0.5.5.0 text-1.2.3.0 unix-2.7.2.2
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh=ea4e8465edaf940bc6b809afec7d8a0c
             microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5=1a8e1231c2e84cbd42a7eb5d31204255
             microlens-th-0.4.2.3-AFinaMAgvMDE4Aie8g4V0i=4722625102482263d661d60f86d2e336
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS=bfa6d2c22d7e7c439a84add8c91d8e7a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             terminfo-0.4.1.1=f198095a593060871f229adb71186f33
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html: /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
